Crate mrot_config

Crate mrot_config 

This crate is now deprecated. It was once used to hold the configuration values for the meal rotator app mrot. Its current form is now fully integrated into the app.

Structs

Ignore
MrotConfig
Show
What